==> ejc-dataexchange-api-3.0.0-20220809.001235-27-sources.jar: com/ejianc/business/dataexchange/vo/CertificateVO.java <==
package com.ejianc.business.dataexchange.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;



public class CertificateVO {
    private static final long serialVersionUID = 1L;



    private String userCode;//员工编号
    private String certificateCode;//证书编号
    private String certificateName;    //证书名称
    private String certificateType;  //证书类型
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private String createTime;  //创建时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private String modTime; //修改时间
    private String userName; //员工姓名
    private String orgCode; //组织编号
    private String deptCode; //部门编号
    private Date orgName;//组织名称
    private String deptName;//组织编号


    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getCertificateCode() {
        return certificateCode;
    }

    public void setCertificateCode(String certificateCode) {
        this.certificateCode = certificateCode;
    }

    public String getCertificateName() {
        return certificateName;
    }

    public void setCertificateName(String certificateName) {
        this.certificateName = certificateName;
    }

    public String getCertificateType() {
        return certificateType;
    }

    public void setCertificateType(String certificateType) {
        this.certificateType = certificateType;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getModTime() {
        return modTime;
    }

    public void setModTime(String modTime) {
        this.modTime = modTime;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getDeptCode() {
        return deptCode;
    }

    public void setDeptCode(String deptCode) {
        this.deptCode = deptCode;
    }

    public Date getOrgName() {
        return orgName;
    }

    public void setOrgName(Date orgName) {
        this.orgName = orgName;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
}

==> ejc-dataexchange-api-3.0.0-20220809.003231-29-sources.jar: com/ejianc/business/dataexchange/vo/CertificateVO.java <==
package com.ejianc.business.dataexchange.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;



public class CertificateVO {
    private static final long serialVersionUID = 1L;



    private String userCode;//员工编号
    private String certificateCode;//证书编号
    private String certificateName;    //证书名称
    private String certificateType;  //证书类型
    //@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private String createTime;  //创建时间
    //@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private String modTime; //修改时间
    private String userName; //员工姓名
    private String orgCode; //组织编号
    private String deptCode; //部门编号
    private Date orgName;//组织名称
    private String deptName;//组织编号


    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getCertificateCode() {
        return certificateCode;
    }

    public void setCertificateCode(String certificateCode) {
        this.certificateCode = certificateCode;
    }

    public String getCertificateName() {
        return certificateName;
    }

    public void setCertificateName(String certificateName) {
        this.certificateName = certificateName;
    }

    public String getCertificateType() {
        return certificateType;
    }

    public void setCertificateType(String certificateType) {
        this.certificateType = certificateType;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getModTime() {
        return modTime;
    }

    public void setModTime(String modTime) {
        this.modTime = modTime;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getDeptCode() {
        return deptCode;
    }

    public void setDeptCode(String deptCode) {
        this.deptCode = deptCode;
    }

    public Date getOrgName() {
        return orgName;
    }

    public void setOrgName(Date orgName) {
        this.orgName = orgName;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
}
